Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaChangeHistoryEvent
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaChangeHistoryEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
A set of changes within a Google Analytics account or its child properties that resulted from the same cause. Common causes would be updates made in the Google Analytics UI, changes from customer support, or automatic Google Analytics system changes.
Instance Attribute Summary collapse
-
#actor_type ⇒ String
The type of actor that made this change.
-
#change_time ⇒ String
Time when change was made.
-
#changes ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaChangeHistoryChange>
A list of changes made in this change history event that fit the filters specified in SearchChangeHistoryEventsRequest.
-
#changes_filtered ⇒ Boolean
(also: #changes_filtered?)
If true, then the list of changes returned was filtered, and does not represent all changes that occurred in this event.
-
#id ⇒ String
ID of this change history event.
-
#user_actor_email ⇒ String
Email address of the Google account that made the change.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaChangeHistoryEvent
constructor
A new instance of GoogleAnalyticsAdminV1alphaChangeHistoryEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaChangeHistoryEvent
Returns a new instance of GoogleAnalyticsAdminV1alphaChangeHistoryEvent.
2021 2022 2023 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actor_type ⇒ String
The type of actor that made this change.
Corresponds to the JSON property actorType
1989 1990 1991 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 1989 def actor_type @actor_type end |
#change_time ⇒ String
Time when change was made.
Corresponds to the JSON property changeTime
1994 1995 1996 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 1994 def change_time @change_time end |
#changes ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaChangeHistoryChange>
A list of changes made in this change history event that fit the filters
specified in SearchChangeHistoryEventsRequest.
Corresponds to the JSON property changes
2000 2001 2002 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2000 def changes @changes end |
#changes_filtered ⇒ Boolean Also known as: changes_filtered?
If true, then the list of changes returned was filtered, and does not
represent all changes that occurred in this event.
Corresponds to the JSON property changesFiltered
2006 2007 2008 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2006 def changes_filtered @changes_filtered end |
#id ⇒ String
ID of this change history event. This ID is unique across Google Analytics.
Corresponds to the JSON property id
2012 2013 2014 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2012 def id @id end |
#user_actor_email ⇒ String
Email address of the Google account that made the change. This will be a valid
email address if the actor field is set to USER, and empty otherwise. Google
accounts that have been deleted will cause an error.
Corresponds to the JSON property userActorEmail
2019 2020 2021 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2019 def user_actor_email @user_actor_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2026 2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2026 def update!(**args) @actor_type = args[:actor_type] if args.key?(:actor_type) @change_time = args[:change_time] if args.key?(:change_time) @changes = args[:changes] if args.key?(:changes) @changes_filtered = args[:changes_filtered] if args.key?(:changes_filtered) @id = args[:id] if args.key?(:id) @user_actor_email = args[:user_actor_email] if args.key?(:user_actor_email) end |