Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaChannelGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A resource message representing a Channel Group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaChannelGroup

Returns a new instance of GoogleAnalyticsAdminV1alphaChannelGroup.



2079
2080
2081
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the Channel Group. Max length of 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


2043
2044
2045
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2043

def description
  @description
end

#display_nameString

Required. The display name of the Channel Group. Max length of 80 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


2048
2049
2050
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2048

def display_name
  @display_name
end

#grouping_ruleArray<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaGroupingRule>

Required. The grouping rules of channels. Maximum number of rules is 50. Corresponds to the JSON property groupingRule



2053
2054
2055
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2053

def grouping_rule
  @grouping_rule
end

#nameString

Output only. The resource name for this Channel Group resource. Format: properties/property/channelGroups/channel_group Corresponds to the JSON property name

Returns:

  • (String)


2059
2060
2061
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2059

def name
  @name
end

#primaryBoolean Also known as: primary?

Optional. If true, this channel group will be used as the default channel group for reports. Only one channel group can be set as primary at any time. If the primary field gets set on a channel group, it will get unset on the previous primary channel group. The Google Analytics predefined channel group is the primary by default. Corresponds to the JSON property primary

Returns:

  • (Boolean)


2068
2069
2070
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2068

def primary
  @primary
end

#system_definedBoolean Also known as: system_defined?

Output only. If true, then this channel group is the Default Channel Group predefined by Google Analytics. Display name and grouping rules cannot be updated for this channel group. Corresponds to the JSON property systemDefined

Returns:

  • (Boolean)


2076
2077
2078
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2076

def system_defined
  @system_defined
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2084

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @grouping_rule = args[:grouping_rule] if args.key?(:grouping_rule)
  @name = args[:name] if args.key?(:name)
  @primary = args[:primary] if args.key?(:primary)
  @system_defined = args[:system_defined] if args.key?(:system_defined)
end