Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaConversionEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A conversion event in a Google Analytics property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaConversionEvent

Returns a new instance of GoogleAnalyticsAdminV1alphaConversionEvent.



2280
2281
2282
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#counting_methodString

Optional. The method by which conversions will be counted across multiple events within a session. If this value is not provided, it will be set to ONCE_PER_EVENT. Corresponds to the JSON property countingMethod

Returns:

  • (String)


2237
2238
2239
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2237

def counting_method
  @counting_method
end

#create_timeString

Output only. Time when this conversion event was created in the property. Corresponds to the JSON property createTime

Returns:

  • (String)


2242
2243
2244
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2242

def create_time
  @create_time
end

#customBoolean Also known as: custom?

Output only. If set to true, this conversion event refers to a custom event. If set to false, this conversion event refers to a default event in GA. Default events typically have special meaning in GA. Default events are usually created for you by the GA system, but in some cases can be created by property admins. Custom events count towards the maximum number of custom conversion events that may be created per property. Corresponds to the JSON property custom

Returns:

  • (Boolean)


2252
2253
2254
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2252

def custom
  @custom
end

#default_conversion_valueGoogle::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaConversionEventDefaultConversionValue

Defines a default value/currency for a conversion event. Both value and currency must be provided. Corresponds to the JSON property defaultConversionValue



2259
2260
2261
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2259

def default_conversion_value
  @default_conversion_value
end

#deletableBoolean Also known as: deletable?

Output only. If set, this event can currently be deleted with DeleteConversionEvent. Corresponds to the JSON property deletable

Returns:

  • (Boolean)


2265
2266
2267
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2265

def deletable
  @deletable
end

#event_nameString

Immutable. The event name for this conversion event. Examples: 'click', ' purchase' Corresponds to the JSON property eventName

Returns:

  • (String)


2272
2273
2274
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2272

def event_name
  @event_name
end

#nameString

Identifier. Resource name of this conversion event. Format: properties/ property/conversionEvents/conversion_event Corresponds to the JSON property name

Returns:

  • (String)


2278
2279
2280
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2278

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2285
2286
2287
2288
2289
2290
2291
2292
2293
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2285

def update!(**args)
  @counting_method = args[:counting_method] if args.key?(:counting_method)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom = args[:custom] if args.key?(:custom)
  @default_conversion_value = args[:default_conversion_value] if args.key?(:default_conversion_value)
  @deletable = args[:deletable] if args.key?(:deletable)
  @event_name = args[:event_name] if args.key?(:event_name)
  @name = args[:name] if args.key?(:name)
end