Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaCustomDimension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A definition for a CustomDimension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaCustomDimension

Returns a new instance of GoogleAnalyticsAdminV1alphaCustomDimension.



2503
2504
2505
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Description for this custom dimension. Max length of 150 characters. Corresponds to the JSON property description

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2463

def description
  @description
end

#disallow_ads_personalizationBoolean Also known as: disallow_ads_personalization?

Optional. If set to true, sets this dimension as NPA and excludes it from ads personalization. This is currently only supported by user-scoped custom dimensions. Corresponds to the JSON property disallowAdsPersonalization

Returns:

  • (Boolean)


2470
2471
2472
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2470

def disallow_ads_personalization
  @disallow_ads_personalization
end

#display_nameString

Required. Display name for this custom dimension as shown in the Analytics UI. Max length of 82 characters, alphanumeric plus space and underscore starting with a letter. Legacy system-generated display names may contain square brackets, but updates to this field will never permit square brackets. Corresponds to the JSON property displayName

Returns:

  • (String)


2479
2480
2481
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2479

def display_name
  @display_name
end

#nameString

Identifier. Resource name for this CustomDimension resource. Format: properties/property/customDimensions/customDimension Corresponds to the JSON property name

Returns:

  • (String)


2485
2486
2487
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2485

def name
  @name
end

#parameter_nameString

Required. Immutable. Tagging parameter name for this custom dimension. If this is a user-scoped dimension, then this is the user property name. If this is an event-scoped dimension, then this is the event parameter name. If this is an item-scoped dimension, then this is the parameter name found in the eCommerce items array. May only contain alphanumeric and underscore characters, starting with a letter. Max length of 24 characters for user-scoped dimensions, 40 characters for event-scoped dimensions. Corresponds to the JSON property parameterName

Returns:

  • (String)


2496
2497
2498
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2496

def parameter_name
  @parameter_name
end

#scopeString

Required. Immutable. The scope of this dimension. Corresponds to the JSON property scope

Returns:

  • (String)


2501
2502
2503
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2501

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2508
2509
2510
2511
2512
2513
2514
2515
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2508

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disallow_ads_personalization = args[:disallow_ads_personalization] if args.key?(:disallow_ads_personalization)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @parameter_name = args[:parameter_name] if args.key?(:parameter_name)
  @scope = args[:scope] if args.key?(:scope)
end