Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaCustomMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A definition for a custom metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaCustomMetric

Returns a new instance of GoogleAnalyticsAdminV1alphaCustomMetric.



2566
2567
2568
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Description for this custom dimension. Max length of 150 characters. Corresponds to the JSON property description

Returns:

  • (String)


2525
2526
2527
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2525

def description
  @description
end

#display_nameString

Required. Display name for this custom metric as shown in the Analytics UI. Max length of 82 characters, alphanumeric plus space and underscore starting with a letter. Legacy system-generated display names may contain square brackets, but updates to this field will never permit square brackets. Corresponds to the JSON property displayName

Returns:

  • (String)


2533
2534
2535
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2533

def display_name
  @display_name
end

#measurement_unitString

Required. The type for the custom metric's value. Corresponds to the JSON property measurementUnit

Returns:

  • (String)


2538
2539
2540
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2538

def measurement_unit
  @measurement_unit
end

#nameString

Identifier. Resource name for this CustomMetric resource. Format: properties/ property/customMetrics/customMetric Corresponds to the JSON property name

Returns:

  • (String)


2544
2545
2546
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2544

def name
  @name
end

#parameter_nameString

Required. Immutable. Tagging name for this custom metric. If this is an event- scoped metric, then this is the event parameter name. May only contain alphanumeric and underscore charactes, starting with a letter. Max length of 40 characters for event-scoped metrics. Corresponds to the JSON property parameterName

Returns:

  • (String)


2552
2553
2554
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2552

def parameter_name
  @parameter_name
end

#restricted_metric_typeArray<String>

Optional. Types of restricted data that this metric may contain. Required for metrics with CURRENCY measurement unit. Must be empty for metrics with a non- CURRENCY measurement unit. Corresponds to the JSON property restrictedMetricType

Returns:

  • (Array<String>)


2559
2560
2561
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2559

def restricted_metric_type
  @restricted_metric_type
end

#scopeString

Required. Immutable. The scope of this custom metric. Corresponds to the JSON property scope

Returns:

  • (String)


2564
2565
2566
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2564

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2571
2572
2573
2574
2575
2576
2577
2578
2579
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2571

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @measurement_unit = args[:measurement_unit] if args.key?(:measurement_unit)
  @name = args[:name] if args.key?(:name)
  @parameter_name = args[:parameter_name] if args.key?(:parameter_name)
  @restricted_metric_type = args[:restricted_metric_type] if args.key?(:restricted_metric_type)
  @scope = args[:scope] if args.key?(:scope)
end