Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaDataStreamWebStreamData
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaDataStreamWebStreamData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
Data specific to web streams.
Instance Attribute Summary collapse
-
#default_uri ⇒ String
Domain name of the web app being measured, or empty.
-
#firebase_app_id ⇒ String
Output only.
-
#measurement_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaDataStreamWebStreamData
constructor
A new instance of GoogleAnalyticsAdminV1alphaDataStreamWebStreamData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaDataStreamWebStreamData
Returns a new instance of GoogleAnalyticsAdminV1alphaDataStreamWebStreamData.
2880 2881 2882 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2880 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_uri ⇒ String
Domain name of the web app being measured, or empty. Example: "http://www.
google.com", "https://www.google.com"
Corresponds to the JSON property defaultUri
2867 2868 2869 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2867 def default_uri @default_uri end |
#firebase_app_id ⇒ String
Output only. ID of the corresponding web app in Firebase, if any. This ID can
change if the web app is deleted and recreated.
Corresponds to the JSON property firebaseAppId
2873 2874 2875 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2873 def firebase_app_id @firebase_app_id end |
#measurement_id ⇒ String
Output only. Analytics Measurement ID. Example: "G-1A2BCD345E"
Corresponds to the JSON property measurementId
2878 2879 2880 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2878 def measurement_id @measurement_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2885 2886 2887 2888 2889 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2885 def update!(**args) @default_uri = args[:default_uri] if args.key?(:default_uri) @firebase_app_id = args[:firebase_app_id] if args.key?(:firebase_app_id) @measurement_id = args[:measurement_id] if args.key?(:measurement_id) end |