Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A link between a Google Analytics property and a Display & Video 360 advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLink

Returns a new instance of GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLink.



2960
2961
2962
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ads_personalization_enabledBoolean Also known as: ads_personalization_enabled?

Enables personalized advertising features with this integration. If this field is not set on create/update, it will be defaulted to true. Corresponds to the JSON property adsPersonalizationEnabled

Returns:

  • (Boolean)


2921
2922
2923
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2921

def ads_personalization_enabled
  @ads_personalization_enabled
end

#advertiser_display_nameString

Output only. The display name of the Display & Video 360 Advertiser. Corresponds to the JSON property advertiserDisplayName

Returns:

  • (String)


2927
2928
2929
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2927

def advertiser_display_name
  @advertiser_display_name
end

#advertiser_idString

Immutable. The Display & Video 360 Advertiser's advertiser ID. Corresponds to the JSON property advertiserId

Returns:

  • (String)


2932
2933
2934
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2932

def advertiser_id
  @advertiser_id
end

#campaign_data_sharing_enabledBoolean Also known as: campaign_data_sharing_enabled?

Immutable. Enables the import of campaign data from Display & Video 360 into the Google Analytics property. After link creation, this can only be updated from the Display & Video 360 product. If this field is not set on create, it will be defaulted to true. Corresponds to the JSON property campaignDataSharingEnabled

Returns:

  • (Boolean)


2940
2941
2942
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2940

def campaign_data_sharing_enabled
  @campaign_data_sharing_enabled
end

#cost_data_sharing_enabledBoolean Also known as: cost_data_sharing_enabled?

Immutable. Enables the import of cost data from Display & Video 360 into the Google Analytics property. This can only be enabled if campaign_data_sharing_enabled is true. After link creation, this can only be updated from the Display & Video 360 product. If this field is not set on create, it will be defaulted to true. Corresponds to the JSON property costDataSharingEnabled

Returns:

  • (Boolean)


2950
2951
2952
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2950

def cost_data_sharing_enabled
  @cost_data_sharing_enabled
end

#nameString

Identifier. The resource name for this DisplayVideo360AdvertiserLink resource. Format: properties/propertyId/displayVideo360AdvertiserLinks/linkId Note: linkId is not the Display & Video 360 Advertiser ID Corresponds to the JSON property name

Returns:

  • (String)


2958
2959
2960
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2958

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2965
2966
2967
2968
2969
2970
2971
2972
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2965

def update!(**args)
  @ads_personalization_enabled = args[:ads_personalization_enabled] if args.key?(:ads_personalization_enabled)
  @advertiser_display_name = args[:advertiser_display_name] if args.key?(:advertiser_display_name)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @campaign_data_sharing_enabled = args[:campaign_data_sharing_enabled] if args.key?(:campaign_data_sharing_enabled)
  @cost_data_sharing_enabled = args[:cost_data_sharing_enabled] if args.key?(:cost_data_sharing_enabled)
  @name = args[:name] if args.key?(:name)
end