Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A proposal for a link between a Google Analytics property and a Display & Video 360 advertiser. A proposal is converted to a DisplayVideo360AdvertiserLink once approved. Google Analytics admins approve inbound proposals while Display & Video 360 admins approve outbound proposals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal

Returns a new instance of GoogleAnalyticsAdminV1alphaDisplayVideo360AdvertiserLinkProposal.



3038
3039
3040
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ads_personalization_enabledBoolean Also known as: ads_personalization_enabled?

Immutable. Enables personalized advertising features with this integration. If this field is not set on create, it will be defaulted to true. Corresponds to the JSON property adsPersonalizationEnabled

Returns:

  • (Boolean)


2986
2987
2988
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2986

def ads_personalization_enabled
  @ads_personalization_enabled
end

#advertiser_display_nameString

Output only. The display name of the Display & Video Advertiser. Only populated for proposals that originated from Display & Video 360. Corresponds to the JSON property advertiserDisplayName

Returns:

  • (String)


2993
2994
2995
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2993

def advertiser_display_name
  @advertiser_display_name
end

#advertiser_idString

Immutable. The Display & Video 360 Advertiser's advertiser ID. Corresponds to the JSON property advertiserId

Returns:

  • (String)


2998
2999
3000
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2998

def advertiser_id
  @advertiser_id
end

#campaign_data_sharing_enabledBoolean Also known as: campaign_data_sharing_enabled?

Immutable. Enables the import of campaign data from Display & Video 360. If this field is not set on create, it will be defaulted to true. Corresponds to the JSON property campaignDataSharingEnabled

Returns:

  • (Boolean)


3004
3005
3006
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3004

def campaign_data_sharing_enabled
  @campaign_data_sharing_enabled
end

#cost_data_sharing_enabledBoolean Also known as: cost_data_sharing_enabled?

Immutable. Enables the import of cost data from Display & Video 360. This can only be enabled if campaign_data_sharing_enabled is enabled. If this field is not set on create, it will be defaulted to true. Corresponds to the JSON property costDataSharingEnabled

Returns:

  • (Boolean)


3012
3013
3014
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3012

def cost_data_sharing_enabled
  @cost_data_sharing_enabled
end

Status information for a link proposal. Corresponds to the JSON property linkProposalStatusDetails



3018
3019
3020
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3018

def link_proposal_status_details
  @link_proposal_status_details
end

#nameString

Identifier. The resource name for this DisplayVideo360AdvertiserLinkProposal resource. Format: properties/propertyId/ displayVideo360AdvertiserLinkProposals/proposalId Note: proposalId is not the Display & Video 360 Advertiser ID Corresponds to the JSON property name

Returns:

  • (String)


3026
3027
3028
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3026

def name
  @name
end

#validation_emailString

Input only. On a proposal being sent to Display & Video 360, this field must be set to the email address of an admin on the target advertiser. This is used to verify that the Google Analytics admin is aware of at least one admin on the Display & Video 360 Advertiser. This does not restrict approval of the proposal to a single user. Any admin on the Display & Video 360 Advertiser may approve the proposal. Corresponds to the JSON property validationEmail

Returns:

  • (String)


3036
3037
3038
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3036

def validation_email
  @validation_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3043

def update!(**args)
  @ads_personalization_enabled = args[:ads_personalization_enabled] if args.key?(:ads_personalization_enabled)
  @advertiser_display_name = args[:advertiser_display_name] if args.key?(:advertiser_display_name)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @campaign_data_sharing_enabled = args[:campaign_data_sharing_enabled] if args.key?(:campaign_data_sharing_enabled)
  @cost_data_sharing_enabled = args[:cost_data_sharing_enabled] if args.key?(:cost_data_sharing_enabled)
  @link_proposal_status_details = args[:link_proposal_status_details] if args.key?(:link_proposal_status_details)
  @name = args[:name] if args.key?(:name)
  @validation_email = args[:validation_email] if args.key?(:validation_email)
end