Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaEventMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

Event setting conditions to match an event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaEventMapping

Returns a new instance of GoogleAnalyticsAdminV1alphaEventMapping.



3303
3304
3305
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_nameString

Required. Name of the Google Analytics event. It must always be set. The max allowed display name length is 40 UTF-16 code units. Corresponds to the JSON property eventName

Returns:

  • (String)


3274
3275
3276
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3274

def event_name
  @event_name
end

#max_event_countFixnum

The maximum number of times the event occurred. If not set, maximum event count won't be checked. Corresponds to the JSON property maxEventCount

Returns:

  • (Fixnum)


3280
3281
3282
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3280

def max_event_count
  @max_event_count
end

#max_event_valueFloat

The maximum revenue generated due to the event. Revenue currency will be defined at the property level. If not set, maximum event value won't be checked. Corresponds to the JSON property maxEventValue

Returns:

  • (Float)


3287
3288
3289
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3287

def max_event_value
  @max_event_value
end

#min_event_countFixnum

At least one of the following four min/max values must be set. The values set will be ANDed together to qualify an event. The minimum number of times the event occurred. If not set, minimum event count won't be checked. Corresponds to the JSON property minEventCount

Returns:

  • (Fixnum)


3294
3295
3296
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3294

def min_event_count
  @min_event_count
end

#min_event_valueFloat

The minimum revenue generated due to the event. Revenue currency will be defined at the property level. If not set, minimum event value won't be checked. Corresponds to the JSON property minEventValue

Returns:

  • (Float)


3301
3302
3303
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3301

def min_event_value
  @min_event_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3308
3309
3310
3311
3312
3313
3314
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3308

def update!(**args)
  @event_name = args[:event_name] if args.key?(:event_name)
  @max_event_count = args[:max_event_count] if args.key?(:max_event_count)
  @max_event_value = args[:max_event_value] if args.key?(:max_event_value)
  @min_event_count = args[:min_event_count] if args.key?(:min_event_count)
  @min_event_value = args[:min_event_value] if args.key?(:min_event_value)
end