Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaGoogleAdsLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A link between a Google Analytics property and a Google Ads account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaGoogleAdsLink

Returns a new instance of GoogleAnalyticsAdminV1alphaGoogleAdsLink.



3630
3631
3632
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ads_personalization_enabledBoolean Also known as: ads_personalization_enabled?

Enable personalized advertising features with this integration. Automatically publish my Google Analytics audience lists and Google Analytics remarketing events/parameters to the linked Google Ads account. If this field is not set on create/update, it will be defaulted to true. Corresponds to the JSON property adsPersonalizationEnabled

Returns:

  • (Boolean)


3594
3595
3596
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3594

def ads_personalization_enabled
  @ads_personalization_enabled
end

#can_manage_clientsBoolean Also known as: can_manage_clients?

Output only. If true, this link is for a Google Ads manager account. Corresponds to the JSON property canManageClients

Returns:

  • (Boolean)


3600
3601
3602
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3600

def can_manage_clients
  @can_manage_clients
end

#create_timeString

Output only. Time when this link was originally created. Corresponds to the JSON property createTime

Returns:

  • (String)


3606
3607
3608
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3606

def create_time
  @create_time
end

#creator_email_addressString

Output only. Email address of the user that created the link. An empty string will be returned if the email address can't be retrieved. Corresponds to the JSON property creatorEmailAddress

Returns:

  • (String)


3612
3613
3614
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3612

def creator_email_address
  @creator_email_address
end

#customer_idString

Immutable. Google Ads customer ID. Corresponds to the JSON property customerId

Returns:

  • (String)


3617
3618
3619
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3617

def customer_id
  @customer_id
end

#nameString

Identifier. Format: properties/propertyId/googleAdsLinks/googleAdsLinkId Note: googleAdsLinkId is not the Google Ads customer ID. Corresponds to the JSON property name

Returns:

  • (String)


3623
3624
3625
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3623

def name
  @name
end

#update_timeString

Output only. Time when this link was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3628
3629
3630
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3628

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3635
3636
3637
3638
3639
3640
3641
3642
3643
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3635

def update!(**args)
  @ads_personalization_enabled = args[:ads_personalization_enabled] if args.key?(:ads_personalization_enabled)
  @can_manage_clients = args[:can_manage_clients] if args.key?(:can_manage_clients)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator_email_address = args[:creator_email_address] if args.key?(:creator_email_address)
  @customer_id = args[:customer_id] if args.key?(:customer_id)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end