Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaKeyEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A key event in a Google Analytics property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaKeyEvent

Returns a new instance of GoogleAnalyticsAdminV1alphaKeyEvent.



3751
3752
3753
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#counting_methodString

Required. The method by which Key Events will be counted across multiple events within a session. Corresponds to the JSON property countingMethod

Returns:

  • (String)


3711
3712
3713
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3711

def counting_method
  @counting_method
end

#create_timeString

Output only. Time when this key event was created in the property. Corresponds to the JSON property createTime

Returns:

  • (String)


3716
3717
3718
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3716

def create_time
  @create_time
end

#customBoolean Also known as: custom?

Output only. If set to true, this key event refers to a custom event. If set to false, this key event refers to a default event in GA. Default events typically have special meaning in GA. Default events are usually created for you by the GA system, but in some cases can be created by property admins. Custom events count towards the maximum number of custom key events that may be created per property. Corresponds to the JSON property custom

Returns:

  • (Boolean)


3726
3727
3728
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3726

def custom
  @custom
end

#default_valueGoogle::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaKeyEventDefaultValue

Defines a default value/currency for a key event. Corresponds to the JSON property defaultValue



3732
3733
3734
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3732

def default_value
  @default_value
end

#deletableBoolean Also known as: deletable?

Output only. If set to true, this event can be deleted. Corresponds to the JSON property deletable

Returns:

  • (Boolean)


3737
3738
3739
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3737

def deletable
  @deletable
end

#event_nameString

Immutable. The event name for this key event. Examples: 'click', 'purchase' Corresponds to the JSON property eventName

Returns:

  • (String)


3743
3744
3745
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3743

def event_name
  @event_name
end

#nameString

Output only. Resource name of this key event. Format: properties/property/ keyEvents/key_event Corresponds to the JSON property name

Returns:

  • (String)


3749
3750
3751
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3749

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3756

def update!(**args)
  @counting_method = args[:counting_method] if args.key?(:counting_method)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom = args[:custom] if args.key?(:custom)
  @default_value = args[:default_value] if args.key?(:default_value)
  @deletable = args[:deletable] if args.key?(:deletable)
  @event_name = args[:event_name] if args.key?(:event_name)
  @name = args[:name] if args.key?(:name)
end