Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaKeyEventDefaultValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

Defines a default value/currency for a key event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaKeyEventDefaultValue

Returns a new instance of GoogleAnalyticsAdminV1alphaKeyEventDefaultValue.



3786
3787
3788
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#currency_codeString

Required. When an occurrence of this Key Event (specified by event_name) has no set currency this currency will be applied as the default. Must be in ISO 4217 currency code format. See https://en.wikipedia.org/wiki/ISO_4217 for more information. Corresponds to the JSON property currencyCode

Returns:

  • (String)


3777
3778
3779
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3777

def currency_code
  @currency_code
end

#numeric_valueFloat

Required. This will be used to populate the "value" parameter for all occurrences of this Key Event (specified by event_name) where that parameter is unset. Corresponds to the JSON property numericValue

Returns:

  • (Float)


3784
3785
3786
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3784

def numeric_value
  @numeric_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3791
3792
3793
3794
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3791

def update!(**args)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @numeric_value = args[:numeric_value] if args.key?(:numeric_value)
end