Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaListAccessBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

Response message for ListAccessBindings RPC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaListAccessBindingsResponse

Returns a new instance of GoogleAnalyticsAdminV1alphaListAccessBindingsResponse.



3844
3845
3846
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_bindingsArray<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessBinding>

List of AccessBindings. These will be ordered stably, but in an arbitrary order. Corresponds to the JSON property accessBindings



3836
3837
3838
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3836

def access_bindings
  @access_bindings
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3842
3843
3844
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3842

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3849
3850
3851
3852
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 3849

def update!(**args)
  @access_bindings = args[:access_bindings] if args.key?(:access_bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end