Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaListFirebaseLinksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

Response message for ListFirebaseLinks RPC

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaListFirebaseLinksResponse

Returns a new instance of GoogleAnalyticsAdminV1alphaListFirebaseLinksResponse.



4290
4291
4292
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

List of FirebaseLinks. This will have at most one value. Corresponds to the JSON property firebaseLinks



4281
4282
4283
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4281

def firebase_links
  @firebase_links
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Currently, Google Analytics supports only one FirebaseLink per property, so this will never be populated. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4288
4289
4290
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4288

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4295
4296
4297
4298
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4295

def update!(**args)
  @firebase_links = args[:firebase_links] if args.key?(:firebase_links)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end