Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaMatchingCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

Defines a condition for when an Event Edit or Event Creation rule applies to an event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaMatchingCondition

Returns a new instance of GoogleAnalyticsAdminV1alphaMatchingCondition.



4595
4596
4597
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comparison_typeString

Required. The type of comparison to be applied to the value. Corresponds to the JSON property comparisonType

Returns:

  • (String)


4571
4572
4573
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4571

def comparison_type
  @comparison_type
end

#fieldString

Required. The name of the field that is compared against for the condition. If 'event_name' is specified this condition will apply to the name of the event. Otherwise the condition will apply to a parameter with the specified name. This value cannot contain spaces. Corresponds to the JSON property field

Returns:

  • (String)


4579
4580
4581
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4579

def field
  @field
end

#negatedBoolean Also known as: negated?

Whether or not the result of the comparison should be negated. For example, if negated is true, then 'equals' comparisons would function as 'not equals'. Corresponds to the JSON property negated

Returns:

  • (Boolean)


4585
4586
4587
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4585

def negated
  @negated
end

#valueString

Required. The value being compared against for this condition. The runtime implementation may perform type coercion of this value to evaluate this condition based on the type of the parameter value. Corresponds to the JSON property value

Returns:

  • (String)


4593
4594
4595
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4593

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4600
4601
4602
4603
4604
4605
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4600

def update!(**args)
  @comparison_type = args[:comparison_type] if args.key?(:comparison_type)
  @field = args[:field] if args.key?(:field)
  @negated = args[:negated] if args.key?(:negated)
  @value = args[:value] if args.key?(:value)
end