Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaMeasurementProtocolSecret

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A secret value used for sending hits to Measurement Protocol.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaMeasurementProtocolSecret

Returns a new instance of GoogleAnalyticsAdminV1alphaMeasurementProtocolSecret.



4631
4632
4633
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. Human-readable display name for this secret. Corresponds to the JSON property displayName

Returns:

  • (String)


4615
4616
4617
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4615

def display_name
  @display_name
end

#nameString

Identifier. Resource name of this secret. This secret may be a child of any type of stream. Format: properties/property/dataStreams/dataStream/ measurementProtocolSecrets/measurementProtocolSecret Corresponds to the JSON property name

Returns:

  • (String)


4622
4623
4624
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4622

def name
  @name
end

#secret_valueString

Output only. The measurement protocol secret value. Pass this value to the api_secret field of the Measurement Protocol API when sending hits to this secret's parent property. Corresponds to the JSON property secretValue

Returns:

  • (String)


4629
4630
4631
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4629

def secret_value
  @secret_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4636
4637
4638
4639
4640
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4636

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @secret_value = args[:secret_value] if args.key?(:secret_value)
end