Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaPropertySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A virtual resource representing metadata for a Google Analytics property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaPropertySummary

Returns a new instance of GoogleAnalyticsAdminV1alphaPropertySummary.



4867
4868
4869
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Display name for the property referred to in this property summary. Corresponds to the JSON property displayName

Returns:

  • (String)


4847
4848
4849
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4847

def display_name
  @display_name
end

#parentString

Resource name of this property's logical parent. Note: The Property-Moving UI can be used to change the parent. Format: accounts/account, properties/ property Example: "accounts/100", "properties/200" Corresponds to the JSON property parent

Returns:

  • (String)


4854
4855
4856
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4854

def parent
  @parent
end

#propertyString

Resource name of property referred to by this property summary Format: properties/property_id Example: "properties/1000" Corresponds to the JSON property property

Returns:

  • (String)


4860
4861
4862
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4860

def property
  @property
end

#property_typeString

The property's property type. Corresponds to the JSON property propertyType

Returns:

  • (String)


4865
4866
4867
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4865

def property_type
  @property_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4872
4873
4874
4875
4876
4877
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4872

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @parent = args[:parent] if args.key?(:parent)
  @property = args[:property] if args.key?(:property)
  @property_type = args[:property_type] if args.key?(:property_type)
end