Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaRunAccessReportRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

The request for a Data Access Record Report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaRunAccessReportRequest

Returns a new instance of GoogleAnalyticsAdminV1alphaRunAccessReportRequest.



5274
5275
5276
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_rangesArray<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessDateRange>

Date ranges of access records to read. If multiple date ranges are requested, each response row will contain a zero based date range index. If two date ranges overlap, the access records for the overlapping days is included in the response rows for both date ranges. Requests are allowed up to 2 date ranges. Corresponds to the JSON property dateRanges



5185
5186
5187
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5185

def date_ranges
  @date_ranges
end

#dimension_filterGoogle::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessFilterExpression

Expresses dimension or metric filters. The fields in the same expression need to be either all dimensions or all metrics. Corresponds to the JSON property dimensionFilter



5191
5192
5193
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5191

def dimension_filter
  @dimension_filter
end

#dimensionsArray<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessDimension>

The dimensions requested and displayed in the response. Requests are allowed up to 9 dimensions. Corresponds to the JSON property dimensions



5197
5198
5199
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5197

def dimensions
  @dimensions
end

#expand_groupsBoolean Also known as: expand_groups?

Optional. Decides whether to return the users within user groups. This field works only when include_all_users is set to true. If true, it will return all users with access to the specified property or account. If false, only the users with direct access will be returned. Corresponds to the JSON property expandGroups

Returns:

  • (Boolean)


5205
5206
5207
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5205

def expand_groups
  @expand_groups
end

#include_all_usersBoolean Also known as: include_all_users?

Optional. Determines whether to include users who have never made an API call in the response. If true, all users with access to the specified property or account are included in the response, regardless of whether they have made an API call or not. If false, only the users who have made an API call will be included. Corresponds to the JSON property includeAllUsers

Returns:

  • (Boolean)


5215
5216
5217
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5215

def include_all_users
  @include_all_users
end

#limitFixnum

The number of rows to return. If unspecified, 10,000 rows are returned. The API returns a maximum of 100,000 rows per request, no matter how many you ask for. limit must be positive. The API may return fewer rows than the requested limit, if there aren't as many remaining rows as the limit. For instance, there are fewer than 300 possible values for the dimension country, so when reporting on only country, you can't get more than 300 rows, even if you set limit to a higher value. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property limit

Returns:

  • (Fixnum)


5229
5230
5231
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5229

def limit
  @limit
end

#metric_filterGoogle::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessFilterExpression

Expresses dimension or metric filters. The fields in the same expression need to be either all dimensions or all metrics. Corresponds to the JSON property metricFilter



5235
5236
5237
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5235

def metric_filter
  @metric_filter
end

#metricsArray<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessMetric>

The metrics requested and displayed in the response. Requests are allowed up to 10 metrics. Corresponds to the JSON property metrics



5241
5242
5243
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5241

def metrics
  @metrics
end

#offsetFixnum

The row count of the start row. The first row is counted as row 0. If offset is unspecified, it is treated as 0. If offset is zero, then this method will return the first page of results with limit entries. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property offset

Returns:

  • (Fixnum)


5250
5251
5252
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5250

def offset
  @offset
end

#order_bysArray<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessOrderBy>

Specifies how rows are ordered in the response. Corresponds to the JSON property orderBys



5255
5256
5257
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5255

def order_bys
  @order_bys
end

#return_entity_quotaBoolean Also known as: return_entity_quota?

Toggles whether to return the current state of this Analytics Property's quota. Quota is returned in AccessQuota. For account-level requests, this field must be false. Corresponds to the JSON property returnEntityQuota

Returns:

  • (Boolean)


5262
5263
5264
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5262

def return_entity_quota
  @return_entity_quota
end

#time_zoneString

This request's time zone if specified. If unspecified, the property's time zone is used. The request's time zone is used to interpret the start & end dates of the report. Formatted as strings from the IANA Time Zone database ( https://www.iana.org/time-zones); for example "America/New_York" or "Asia/ Tokyo". Corresponds to the JSON property timeZone

Returns:

  • (String)


5272
5273
5274
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5272

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5279

def update!(**args)
  @date_ranges = args[:date_ranges] if args.key?(:date_ranges)
  @dimension_filter = args[:dimension_filter] if args.key?(:dimension_filter)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @expand_groups = args[:expand_groups] if args.key?(:expand_groups)
  @include_all_users = args[:include_all_users] if args.key?(:include_all_users)
  @limit = args[:limit] if args.key?(:limit)
  @metric_filter = args[:metric_filter] if args.key?(:metric_filter)
  @metrics = args[:metrics] if args.key?(:metrics)
  @offset = args[:offset] if args.key?(:offset)
  @order_bys = args[:order_bys] if args.key?(:order_bys)
  @return_entity_quota = args[:return_entity_quota] if args.key?(:return_entity_quota)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end