Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
A clause for defining a filter. A filter may be inclusive (events satisfying the filter clause are included in the subproperty's data) or exclusive (events satisfying the filter clause are excluded from the subproperty's data).
Instance Attribute Summary collapse
-
#filter_clause_type ⇒ String
Required.
-
#filter_expression ⇒ Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilterExpression
A logical expression of Subproperty event filters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause
constructor
A new instance of GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause
Returns a new instance of GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause.
5685 5686 5687 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter_clause_type ⇒ String
Required. The type for the filter clause.
Corresponds to the JSON property filterClauseType
5678 5679 5680 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5678 def filter_clause_type @filter_clause_type end |
#filter_expression ⇒ Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilterExpression
A logical expression of Subproperty event filters.
Corresponds to the JSON property filterExpression
5683 5684 5685 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5683 def filter_expression @filter_expression end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5690 5691 5692 5693 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5690 def update!(**args) @filter_clause_type = args[:filter_clause_type] if args.key?(:filter_clause_type) @filter_expression = args[:filter_expression] if args.key?(:filter_expression) end |