Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertySyncConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

Subproperty synchronization configuration controls how ordinary property configurations are synchronized to subproperties. This resource is provisioned automatically for each subproperty.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSubpropertySyncConfig

Returns a new instance of GoogleAnalyticsAdminV1alphaSubpropertySyncConfig.



5832
5833
5834
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apply_to_propertyString

Output only. Immutable. Resource name of the subproperty that these settings apply to. Corresponds to the JSON property applyToProperty

Returns:

  • (String)


5813
5814
5815
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5813

def apply_to_property
  @apply_to_property
end

#custom_dimension_and_metric_sync_modeString

Required. Specifies the Custom Dimension / Metric synchronization mode for the subproperty. If set to ALL, Custom Dimension / Metric synchronization will be immediately enabled. Local configuration of Custom Dimensions / Metrics will not be allowed on the subproperty so long as the synchronization mode is set to ALL. If set to NONE, Custom Dimensions / Metric synchronization is disabled. Custom Dimensions / Metrics must be configured explicitly on the Subproperty. Corresponds to the JSON property customDimensionAndMetricSyncMode

Returns:

  • (String)


5823
5824
5825
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5823

def custom_dimension_and_metric_sync_mode
  @custom_dimension_and_metric_sync_mode
end

#nameString

Output only. Identifier. Format: properties/ordinary_property_id/ subpropertySyncConfigs/subproperty_id Example: properties/1234/ subpropertySyncConfigs/5678 Corresponds to the JSON property name

Returns:

  • (String)


5830
5831
5832
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5830

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5837
5838
5839
5840
5841
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5837

def update!(**args)
  @apply_to_property = args[:apply_to_property] if args.key?(:apply_to_property)
  @custom_dimension_and_metric_sync_mode = args[:custom_dimension_and_metric_sync_mode] if args.key?(:custom_dimension_and_metric_sync_mode)
  @name = args[:name] if args.key?(:name)
end