Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaDataSharingSettings
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaDataSharingSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
A resource message representing data sharing settings of a Google Analytics account.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#sharing_with_google_any_sales_enabled ⇒ Boolean
(also: #sharing_with_google_any_sales_enabled?)
Deprecated.
-
#sharing_with_google_assigned_sales_enabled ⇒ Boolean
(also: #sharing_with_google_assigned_sales_enabled?)
Allows Google access to your Google Analytics account data, including account usage and configuration data, product spending, and users associated with your Google Analytics account, so that Google can help you make the most of Google products, providing you with insights, offers, recommendations, and optimization tips across Google Analytics and other Google products for business.
-
#sharing_with_google_products_enabled ⇒ Boolean
(also: #sharing_with_google_products_enabled?)
Allows Google to use the data to improve other Google products or services.
-
#sharing_with_google_support_enabled ⇒ Boolean
(also: #sharing_with_google_support_enabled?)
Allows Google technical support representatives access to your Google Analytics data and account when necessary to provide service and find solutions to technical issues.
-
#sharing_with_others_enabled ⇒ Boolean
(also: #sharing_with_others_enabled?)
Enable features like predictions, modeled data, and benchmarking that can provide you with richer business insights when you contribute aggregated measurement data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaDataSharingSettings
constructor
A new instance of GoogleAnalyticsAdminV1alphaDataSharingSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaDataSharingSettings
Returns a new instance of GoogleAnalyticsAdminV1alphaDataSharingSettings.
2727 2728 2729 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. Resource name. Format: accounts/account/dataSharingSettings
Example: "accounts/1000/dataSharingSettings"
Corresponds to the JSON property name
2679 2680 2681 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2679 def name @name end |
#sharing_with_google_any_sales_enabled ⇒ Boolean Also known as:
Deprecated. This field is no longer used and always returns false.
Corresponds to the JSON property sharingWithGoogleAnySalesEnabled
2684 2685 2686 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2684 def sharing_with_google_any_sales_enabled @sharing_with_google_any_sales_enabled end |
#sharing_with_google_assigned_sales_enabled ⇒ Boolean Also known as:
Allows Google access to your Google Analytics account data, including account
usage and configuration data, product spending, and users associated with your
Google Analytics account, so that Google can help you make the most of Google
products, providing you with insights, offers, recommendations, and
optimization tips across Google Analytics and other Google products for
business. This field maps to the "Recommendations for your business" field in
the Google Analytics Admin UI.
Corresponds to the JSON property sharingWithGoogleAssignedSalesEnabled
2696 2697 2698 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2696 def sharing_with_google_assigned_sales_enabled @sharing_with_google_assigned_sales_enabled end |
#sharing_with_google_products_enabled ⇒ Boolean Also known as:
Allows Google to use the data to improve other Google products or services.
This fields maps to the "Google products & services" field in the Google
Analytics Admin UI.
Corresponds to the JSON property sharingWithGoogleProductsEnabled
2704 2705 2706 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2704 def sharing_with_google_products_enabled @sharing_with_google_products_enabled end |
#sharing_with_google_support_enabled ⇒ Boolean Also known as:
Allows Google technical support representatives access to your Google
Analytics data and account when necessary to provide service and find
solutions to technical issues. This field maps to the "Technical support"
field in the Google Analytics Admin UI.
Corresponds to the JSON property sharingWithGoogleSupportEnabled
2713 2714 2715 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2713 def sharing_with_google_support_enabled @sharing_with_google_support_enabled end |
#sharing_with_others_enabled ⇒ Boolean Also known as:
Enable features like predictions, modeled data, and benchmarking that can
provide you with richer business insights when you contribute aggregated
measurement data. The data you share (including information about the property
from which it is shared) is aggregated and de-identified before being used to
generate business insights. This field maps to the "Modeling contributions &
business insights" field in the Google Analytics Admin UI.
Corresponds to the JSON property sharingWithOthersEnabled
2724 2725 2726 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2724 def sharing_with_others_enabled @sharing_with_others_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2732 2733 2734 2735 2736 2737 2738 2739 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 2732 def update!(**args) @name = args[:name] if args.key?(:name) @sharing_with_google_any_sales_enabled = args[:sharing_with_google_any_sales_enabled] if args.key?(:sharing_with_google_any_sales_enabled) @sharing_with_google_assigned_sales_enabled = args[:sharing_with_google_assigned_sales_enabled] if args.key?(:sharing_with_google_assigned_sales_enabled) @sharing_with_google_products_enabled = args[:sharing_with_google_products_enabled] if args.key?(:sharing_with_google_products_enabled) @sharing_with_google_support_enabled = args[:sharing_with_google_support_enabled] if args.key?(:sharing_with_google_support_enabled) @sharing_with_others_enabled = args[:sharing_with_others_enabled] if args.key?(:sharing_with_others_enabled) end |