Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaPostbackWindow
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaPostbackWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
Settings for a SKAdNetwork conversion postback window.
Instance Attribute Summary collapse
-
#conversion_values ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaConversionValues>
Ordering of the repeated field will be used to prioritize the conversion value settings.
-
#postback_window_settings_enabled ⇒ Boolean
(also: #postback_window_settings_enabled?)
If enable_postback_window_settings is true, conversion_values must be populated and will be used for determining when and how to set the Conversion Value on a client device and exporting schema to linked Ads accounts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaPostbackWindow
constructor
A new instance of GoogleAnalyticsAdminV1alphaPostbackWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaPostbackWindow
Returns a new instance of GoogleAnalyticsAdminV1alphaPostbackWindow.
4723 4724 4725 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4723 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_values ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaConversionValues>
Ordering of the repeated field will be used to prioritize the conversion value
settings. Lower indexed entries are prioritized higher. The first conversion
value setting that evaluates to true will be selected. It must have at least
one entry if enable_postback_window_settings is set to true. It can have
maximum of 128 entries.
Corresponds to the JSON property conversionValues
4711 4712 4713 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4711 def conversion_values @conversion_values end |
#postback_window_settings_enabled ⇒ Boolean Also known as: postback_window_settings_enabled?
If enable_postback_window_settings is true, conversion_values must be
populated and will be used for determining when and how to set the Conversion
Value on a client device and exporting schema to linked Ads accounts. If false,
the settings are not used, but are retained in case they may be used in the
future. This must always be true for postback_window_one.
Corresponds to the JSON property postbackWindowSettingsEnabled
4720 4721 4722 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4720 def postback_window_settings_enabled @postback_window_settings_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4728 4729 4730 4731 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4728 def update!(**args) @conversion_values = args[:conversion_values] if args.key?(:conversion_values) @postback_window_settings_enabled = args[:postback_window_settings_enabled] if args.key?(:postback_window_settings_enabled) end |