Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaProperty
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaProperty
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
A resource message representing a Google Analytics property.
Instance Attribute Summary collapse
-
#account ⇒ String
Immutable.
-
#create_time ⇒ String
Output only.
-
#currency_code ⇒ String
The currency type used in reports involving monetary values.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#expire_time ⇒ String
Output only.
-
#industry_category ⇒ String
Industry associated with this property Example: AUTOMOTIVE, FOOD_AND_DRINK Corresponds to the JSON property
industryCategory. -
#name ⇒ String
Identifier.
-
#parent ⇒ String
Immutable.
-
#property_type ⇒ String
Immutable.
-
#service_level ⇒ String
Output only.
-
#time_zone ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaProperty
constructor
A new instance of GoogleAnalyticsAdminV1alphaProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaProperty
Returns a new instance of GoogleAnalyticsAdminV1alphaProperty.
4818 4819 4820 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4818 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account ⇒ String
Immutable. The resource name of the parent account Format: accounts/
account_id Example: "accounts/123"
Corresponds to the JSON property account
4742 4743 4744 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4742 def account @account end |
#create_time ⇒ String
Output only. Time when the entity was originally created.
Corresponds to the JSON property createTime
4747 4748 4749 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4747 def create_time @create_time end |
#currency_code ⇒ String
The currency type used in reports involving monetary values. Format: https://
en.wikipedia.org/wiki/ISO_4217 Examples: "USD", "EUR", "JPY"
Corresponds to the JSON property currencyCode
4753 4754 4755 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4753 def currency_code @currency_code end |
#delete_time ⇒ String
Output only. If set, the time at which this property was trashed. If not set,
then this property is not currently in the trash can.
Corresponds to the JSON property deleteTime
4759 4760 4761 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4759 def delete_time @delete_time end |
#display_name ⇒ String
Required. Human-readable display name for this property. The max allowed
display name length is 100 UTF-16 code units.
Corresponds to the JSON property displayName
4765 4766 4767 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4765 def display_name @display_name end |
#expire_time ⇒ String
Output only. If set, the time at which this trashed property will be
permanently deleted. If not set, then this property is not currently in the
trash can and is not slated to be deleted.
Corresponds to the JSON property expireTime
4772 4773 4774 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4772 def expire_time @expire_time end |
#industry_category ⇒ String
Industry associated with this property Example: AUTOMOTIVE, FOOD_AND_DRINK
Corresponds to the JSON property industryCategory
4777 4778 4779 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4777 def industry_category @industry_category end |
#name ⇒ String
Identifier. Resource name of this property. Format: properties/property_id
Example: "properties/1000"
Corresponds to the JSON property name
4783 4784 4785 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4783 def name @name end |
#parent ⇒ String
Immutable. Resource name of this property's logical parent. Note: The Property-
Moving UI can be used to change the parent. Format: accounts/account,
properties/property Example: "accounts/100", "properties/101"
Corresponds to the JSON property parent
4790 4791 4792 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4790 def parent @parent end |
#property_type ⇒ String
Immutable. The property type for this Property resource. When creating a
property, if the type is "PROPERTY_TYPE_UNSPECIFIED", then "ORDINARY_PROPERTY"
will be implied.
Corresponds to the JSON property propertyType
4797 4798 4799 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4797 def property_type @property_type end |
#service_level ⇒ String
Output only. The Google Analytics service level that applies to this property.
Corresponds to the JSON property serviceLevel
4802 4803 4804 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4802 def service_level @service_level end |
#time_zone ⇒ String
Required. Reporting Time Zone, used as the day boundary for reports,
regardless of where the data originates. If the time zone honors DST,
Analytics will automatically adjust for the changes. NOTE: Changing the time
zone only affects data going forward, and is not applied retroactively. Format:
https://www.iana.org/time-zones Example: "America/Los_Angeles"
Corresponds to the JSON property timeZone
4811 4812 4813 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4811 def time_zone @time_zone end |
#update_time ⇒ String
Output only. Time when entity payload fields were last updated.
Corresponds to the JSON property updateTime
4816 4817 4818 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4816 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4823 4824 4825 4826 4827 4828 4829 4830 4831 4832 4833 4834 4835 4836 4837 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 4823 def update!(**args) @account = args[:account] if args.key?(:account) @create_time = args[:create_time] if args.key?(:create_time) @currency_code = args[:currency_code] if args.key?(:currency_code) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @industry_category = args[:industry_category] if args.key?(:industry_category) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @property_type = args[:property_type] if args.key?(:property_type) @service_level = args[:service_level] if args.key?(:service_level) @time_zone = args[:time_zone] if args.key?(:time_zone) @update_time = args[:update_time] if args.key?(:update_time) end |