Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaRunAccessReportResponse
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaRunAccessReportResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
The customized Data Access Record Report response.
Instance Attribute Summary collapse
-
#dimension_headers ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessDimensionHeader>
The header for a column in the report that corresponds to a specific dimension.
-
#metric_headers ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessMetricHeader>
The header for a column in the report that corresponds to a specific metric.
-
#quota ⇒ Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessQuota
Current state of all quotas for this Analytics property.
-
#row_count ⇒ Fixnum
The total number of rows in the query result.
-
#rows ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessRow>
Rows of dimension value combinations and metric values in the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaRunAccessReportResponse
constructor
A new instance of GoogleAnalyticsAdminV1alphaRunAccessReportResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaRunAccessReportResponse
Returns a new instance of GoogleAnalyticsAdminV1alphaRunAccessReportResponse.
5328 5329 5330 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension_headers ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessDimensionHeader>
The header for a column in the report that corresponds to a specific dimension.
The number of DimensionHeaders and ordering of DimensionHeaders matches the
dimensions present in rows.
Corresponds to the JSON property dimensionHeaders
5296 5297 5298 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5296 def dimension_headers @dimension_headers end |
#metric_headers ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessMetricHeader>
The header for a column in the report that corresponds to a specific metric.
The number of MetricHeaders and ordering of MetricHeaders matches the metrics
present in rows.
Corresponds to the JSON property metricHeaders
5303 5304 5305 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5303 def metric_headers @metric_headers end |
#quota ⇒ Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessQuota
Current state of all quotas for this Analytics property. If any quota for a
property is exhausted, all requests to that property will return Resource
Exhausted errors.
Corresponds to the JSON property quota
5310 5311 5312 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5310 def quota @quota end |
#row_count ⇒ Fixnum
The total number of rows in the query result. rowCount is independent of the
number of rows returned in the response, the limit request parameter, and
the offset request parameter. For example if a query returns 175 rows and
includes limit of 50 in the API request, the response will contain rowCount
of 175 but only 50 rows. To learn more about this pagination parameter, see
Pagination.
Corresponds to the JSON property rowCount
5321 5322 5323 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5321 def row_count @row_count end |
#rows ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaAccessRow>
Rows of dimension value combinations and metric values in the report.
Corresponds to the JSON property rows
5326 5327 5328 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5326 def rows @rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5333 5334 5335 5336 5337 5338 5339 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5333 def update!(**args) @dimension_headers = args[:dimension_headers] if args.key?(:dimension_headers) @metric_headers = args[:metric_headers] if args.key?(:metric_headers) @quota = args[:quota] if args.key?(:quota) @row_count = args[:row_count] if args.key?(:row_count) @rows = args[:rows] if args.key?(:rows) end |