Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSearchAds360Link
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSearchAds360Link
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
A link between a Google Analytics property and a Search Ads 360 entity.
Instance Attribute Summary collapse
-
#ads_personalization_enabled ⇒ Boolean
(also: #ads_personalization_enabled?)
Enables personalized advertising features with this integration.
-
#advertiser_display_name ⇒ String
Output only.
-
#advertiser_id ⇒ String
Immutable.
-
#campaign_data_sharing_enabled ⇒ Boolean
(also: #campaign_data_sharing_enabled?)
Immutable.
-
#cost_data_sharing_enabled ⇒ Boolean
(also: #cost_data_sharing_enabled?)
Immutable.
-
#name ⇒ String
Identifier.
-
#site_stats_sharing_enabled ⇒ Boolean
(also: #site_stats_sharing_enabled?)
Enables export of site stats with this integration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSearchAds360Link
constructor
A new instance of GoogleAnalyticsAdminV1alphaSearchAds360Link.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSearchAds360Link
Returns a new instance of GoogleAnalyticsAdminV1alphaSearchAds360Link.
5447 5448 5449 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ads_personalization_enabled ⇒ Boolean Also known as: ads_personalization_enabled?
Enables personalized advertising features with this integration. If this field
is not set on create, it will be defaulted to true.
Corresponds to the JSON property adsPersonalizationEnabled
5400 5401 5402 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5400 def ads_personalization_enabled @ads_personalization_enabled end |
#advertiser_display_name ⇒ String
Output only. The display name of the Search Ads 360 Advertiser. Allows users
to easily identify the linked resource.
Corresponds to the JSON property advertiserDisplayName
5407 5408 5409 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5407 def advertiser_display_name @advertiser_display_name end |
#advertiser_id ⇒ String
Immutable. This field represents the Advertiser ID of the Search Ads 360
Advertiser. that has been linked.
Corresponds to the JSON property advertiserId
5413 5414 5415 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5413 def advertiser_id @advertiser_id end |
#campaign_data_sharing_enabled ⇒ Boolean Also known as: campaign_data_sharing_enabled?
Immutable. Enables the import of campaign data from Search Ads 360 into the
Google Analytics property. After link creation, this can only be updated from
the Search Ads 360 product. If this field is not set on create, it will be
defaulted to true.
Corresponds to the JSON property campaignDataSharingEnabled
5421 5422 5423 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5421 def campaign_data_sharing_enabled @campaign_data_sharing_enabled end |
#cost_data_sharing_enabled ⇒ Boolean Also known as: cost_data_sharing_enabled?
Immutable. Enables the import of cost data from Search Ads 360 to the Google
Analytics property. This can only be enabled if campaign_data_sharing_enabled
is enabled. After link creation, this can only be updated from the Search Ads
360 product. If this field is not set on create, it will be defaulted to true.
Corresponds to the JSON property costDataSharingEnabled
5430 5431 5432 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5430 def cost_data_sharing_enabled @cost_data_sharing_enabled end |
#name ⇒ String
Identifier. The resource name for this SearchAds360Link resource. Format:
properties/propertyId/searchAds360Links/linkId Note: linkId is not the
Search Ads 360 advertiser ID
Corresponds to the JSON property name
5438 5439 5440 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5438 def name @name end |
#site_stats_sharing_enabled ⇒ Boolean Also known as: site_stats_sharing_enabled?
Enables export of site stats with this integration. If this field is not set
on create, it will be defaulted to true.
Corresponds to the JSON property siteStatsSharingEnabled
5444 5445 5446 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5444 def site_stats_sharing_enabled @site_stats_sharing_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5452 5453 5454 5455 5456 5457 5458 5459 5460 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5452 def update!(**args) @ads_personalization_enabled = args[:ads_personalization_enabled] if args.key?(:ads_personalization_enabled) @advertiser_display_name = args[:advertiser_display_name] if args.key?(:advertiser_display_name) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @campaign_data_sharing_enabled = args[:campaign_data_sharing_enabled] if args.key?(:campaign_data_sharing_enabled) @cost_data_sharing_enabled = args[:cost_data_sharing_enabled] if args.key?(:cost_data_sharing_enabled) @name = args[:name] if args.key?(:name) @site_stats_sharing_enabled = args[:site_stats_sharing_enabled] if args.key?(:site_stats_sharing_enabled) end |