Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
Request message for SearchChangeHistoryEvents RPC.
Instance Attribute Summary collapse
-
#action ⇒ Array<String>
Optional.
-
#actor_email ⇒ Array<String>
Optional.
-
#earliest_change_time ⇒ String
Optional.
-
#latest_change_time ⇒ String
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#property ⇒ String
Optional.
-
#resource_type ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest
constructor
A new instance of GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest
Returns a new instance of GoogleAnalyticsAdminV1alphaSearchChangeHistoryEventsRequest.
5520 5521 5522 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Array<String>
Optional. If set, only return changes that match one or more of these types of
actions.
Corresponds to the JSON property action
5471 5472 5473 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5471 def action @action end |
#actor_email ⇒ Array<String>
Optional. If set, only return changes if they are made by a user in this list.
Corresponds to the JSON property actorEmail
5476 5477 5478 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5476 def actor_email @actor_email end |
#earliest_change_time ⇒ String
Optional. If set, only return changes made after this time (inclusive).
Corresponds to the JSON property earliestChangeTime
5481 5482 5483 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5481 def earliest_change_time @earliest_change_time end |
#latest_change_time ⇒ String
Optional. If set, only return changes made before this time (inclusive).
Corresponds to the JSON property latestChangeTime
5486 5487 5488 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5486 def latest_change_time @latest_change_time end |
#page_size ⇒ Fixnum
Optional. The maximum number of ChangeHistoryEvent items to return. If
unspecified, at most 50 items will be returned. The maximum value is 200 (
higher values will be coerced to the maximum). Note that the service may
return a page with fewer items than this value specifies (potentially even
zero), and that there still may be additional pages. If you want a particular
number of items, you'll need to continue requesting additional pages using
page_token until you get the needed number.
Corresponds to the JSON property pageSize
5497 5498 5499 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5497 def page_size @page_size end |
#page_token ⇒ String
Optional. A page token, received from a previous SearchChangeHistoryEvents
call. Provide this to retrieve the subsequent page. When paginating, all other
parameters provided to SearchChangeHistoryEvents must match the call that
provided the page token.
Corresponds to the JSON property pageToken
5505 5506 5507 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5505 def page_token @page_token end |
#property ⇒ String
Optional. Resource name for a child property. If set, only return changes made
to this property or its child resources. Format: properties/propertyId
Example: properties/100
Corresponds to the JSON property property
5512 5513 5514 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5512 def property @property end |
#resource_type ⇒ Array<String>
Optional. If set, only return changes if they are for a resource that matches
at least one of these types.
Corresponds to the JSON property resourceType
5518 5519 5520 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5518 def resource_type @resource_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5525 def update!(**args) @action = args[:action] if args.key?(:action) @actor_email = args[:actor_email] if args.key?(:actor_email) @earliest_change_time = args[:earliest_change_time] if args.key?(:earliest_change_time) @latest_change_time = args[:latest_change_time] if args.key?(:latest_change_time) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @property = args[:property] if args.key?(:property) @resource_type = args[:resource_type] if args.key?(:resource_type) end |