Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSkAdNetworkConversionValueSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

SKAdNetwork conversion value schema of an iOS stream.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSkAdNetworkConversionValueSchema

Returns a new instance of GoogleAnalyticsAdminV1alphaSkAdNetworkConversionValueSchema.



5378
5379
5380
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apply_conversion_valuesBoolean Also known as: apply_conversion_values?

If enabled, the GA SDK will set conversion values using this schema definition, and schema will be exported to any Google Ads accounts linked to this property. If disabled, the GA SDK will not automatically set conversion values, and also the schema will not be exported to Ads. Corresponds to the JSON property applyConversionValues

Returns:

  • (Boolean)


5352
5353
5354
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5352

def apply_conversion_values
  @apply_conversion_values
end

#nameString

Identifier. Resource name of the schema. This will be child of ONLY an iOS stream, and there can be at most one such child under an iOS stream. Format: properties/property/dataStreams/dataStream/ sKAdNetworkConversionValueSchema Corresponds to the JSON property name

Returns:

  • (String)


5361
5362
5363
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5361

def name
  @name
end

#postback_window_oneGoogle::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaPostbackWindow

Settings for a SKAdNetwork conversion postback window. Corresponds to the JSON property postbackWindowOne



5366
5367
5368
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5366

def postback_window_one
  @postback_window_one
end

#postback_window_threeGoogle::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaPostbackWindow

Settings for a SKAdNetwork conversion postback window. Corresponds to the JSON property postbackWindowThree



5371
5372
5373
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5371

def postback_window_three
  @postback_window_three
end

#postback_window_twoGoogle::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaPostbackWindow

Settings for a SKAdNetwork conversion postback window. Corresponds to the JSON property postbackWindowTwo



5376
5377
5378
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5376

def postback_window_two
  @postback_window_two
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5383
5384
5385
5386
5387
5388
5389
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5383

def update!(**args)
  @apply_conversion_values = args[:apply_conversion_values] if args.key?(:apply_conversion_values)
  @name = args[:name] if args.key?(:name)
  @postback_window_one = args[:postback_window_one] if args.key?(:postback_window_one)
  @postback_window_three = args[:postback_window_three] if args.key?(:postback_window_three)
  @postback_window_two = args[:postback_window_two] if args.key?(:postback_window_two)
end