Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilter
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb
Overview
A resource message representing a Google Analytics subproperty event filter.
Instance Attribute Summary collapse
-
#apply_to_property ⇒ String
Immutable.
-
#filter_clauses ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause>
Required.
-
#name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSubpropertyEventFilter
constructor
A new instance of GoogleAnalyticsAdminV1alphaSubpropertyEventFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSubpropertyEventFilter
Returns a new instance of GoogleAnalyticsAdminV1alphaSubpropertyEventFilter.
5657 5658 5659 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apply_to_property ⇒ String
Immutable. Resource name of the Subproperty that uses this filter.
Corresponds to the JSON property applyToProperty
5641 5642 5643 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5641 def apply_to_property @apply_to_property end |
#filter_clauses ⇒ Array<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause>
Required. Unordered list. Filter clauses that define the
SubpropertyEventFilter. All clauses are AND'ed together to determine what data
is sent to the subproperty.
Corresponds to the JSON property filterClauses
5648 5649 5650 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5648 def filter_clauses @filter_clauses end |
#name ⇒ String
Output only. Format: properties/ordinary_property_id/subpropertyEventFilters/
sub_property_event_filter Example: properties/1234/subpropertyEventFilters/
5678
Corresponds to the JSON property name
5655 5656 5657 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5655 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5662 5663 5664 5665 5666 |
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5662 def update!(**args) @apply_to_property = args[:apply_to_property] if args.key?(:apply_to_property) @filter_clauses = args[:filter_clauses] if args.key?(:filter_clauses) @name = args[:name] if args.key?(:name) end |