Class: Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1alpha/classes.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb,
lib/google/apis/analyticsadmin_v1alpha/representations.rb

Overview

A resource message representing a Google Analytics subproperty event filter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1alphaSubpropertyEventFilter

Returns a new instance of GoogleAnalyticsAdminV1alphaSubpropertyEventFilter.



5649
5650
5651
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apply_to_propertyString

Immutable. Resource name of the Subproperty that uses this filter. Corresponds to the JSON property applyToProperty

Returns:

  • (String)


5633
5634
5635
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5633

def apply_to_property
  @apply_to_property
end

#filter_clausesArray<Google::Apis::AnalyticsadminV1alpha::GoogleAnalyticsAdminV1alphaSubpropertyEventFilterClause>

Required. Unordered list. Filter clauses that define the SubpropertyEventFilter. All clauses are AND'ed together to determine what data is sent to the subproperty. Corresponds to the JSON property filterClauses



5640
5641
5642
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5640

def filter_clauses
  @filter_clauses
end

#nameString

Output only. Format: properties/ordinary_property_id/subpropertyEventFilters/ sub_property_event_filter Example: properties/1234/subpropertyEventFilters/ 5678 Corresponds to the JSON property name

Returns:

  • (String)


5647
5648
5649
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5647

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5654
5655
5656
5657
5658
# File 'lib/google/apis/analyticsadmin_v1alpha/classes.rb', line 5654

def update!(**args)
  @apply_to_property = args[:apply_to_property] if args.key?(:apply_to_property)
  @filter_clauses = args[:filter_clauses] if args.key?(:filter_clauses)
  @name = args[:name] if args.key?(:name)
end